@@ -128,8 +128,8 @@ class MQ(object):
         try:
             return self.client.xgroup_create(name, group, id=consumeID, mkstream=True)
         except redis.RedisError as e:
-            tracebackInfo = traceback.format_exc()
-            logger.debug(f"Redis create queue error: {tracebackInfo}")
+            # tracebackInfo = traceback.format_exc()
+            logger.warn(f"Redis create queue error: {e}")
             if not existOk:
                 raise error.MQError(f"Redis queue {name} existed") from e
             return None
